==> librenms-1.26v0.tgz: librenms/doc/index.md <==
hide_toc: true
<div class="row">
    <div class="col-md-4">
        <div class="well">
            <div class="home-header">
                <i class="fa fa-download fa-2x"></i>
                <span> Installing</span>
            </div>
            <br />
            <a href="/Installation/Installation-Ubuntu-1604-Nginx/">Ubuntu 16.04 + Nginx</a><br />
            <a href="/Installation/Installation-CentOS-7-Nginx/">CentOS 7 + Nginx</a><br />
            <a href="/Installation/Migrating-from-Observium/">Migrating from Observium</a><br />
            <a href="/Installation/Installing-LibreNMS/"><strong>More...</strong></a>
        </div>
    </div>
    <div class="col-md-4">
        <div class="well">
            <div class="home-header">
                <i class="fa fa-plug fa-2x"></i>
                <span> Extensions</span>
            </div>
            <br />
            <a href="/Extensions/Auto-Discovery/">Auto Discovery</a><br />
            <a href="/Extensions/Oxidized/">Oxidized</a><br />
            <a href="/Extensions/RRDCached/">RRDCached</a><br />
            <strong>More...</strong>
        </div>
    </div>
    <div class="col-md-4">
        <div class="well">
            <div class="home-header">
                <i class="fa fa-bell fa-2x"></i>
                <span> Alerting</span>
            </div>
            <br />
            <a href="/Extensions/Alerting/#rules">Rules</a><br />
            <a href="/Extensions/Alerting/#templates">Templates</a><br />
            <a href="/Extensions/Alerting/#transports">Transports</a><br />
            <a href="/Extensions/Alerting/"><strong>More...</strong></a>
        </div>
    </div>
</div>
<div class="row">
    <div class="col-md-4">
        <div class="well">
            <div class="home-header">
                <i class="fa fa-connectdevelop fa-2x"></i>
                <span> API</span>
            </div>
            <br />
            <a href="/API/API-Docs/">API Docs</a><br />
            <a href="/API/API-Docs/#api-structure">API Structure</a><br />
            <a href="/API/API-Docs/#api-endpoints">API Endpoints</a><br />
            <a href="/API/API-Docs/"><strong>More...</strong></a>
        </div>
    </div>
    <div class="col-md-4">
        <div class="well">
            <div class="home-header">
                <i class="fa fa-ambulance fa-2x"></i>
                <span> Support</span>
            </div>
            <br />
            <a href="/Support/FAQ/">FAQ</a><br />
            <a href="/Support/Install%20Validation/">Install validation</a><br />
            <a href="/Support/Performance/">Performance tweaks</a><br />
            <strong>More...</strong>
        </div>
    </div>
    <div class="col-md-4">
        <div class="well">
            <div class="home-header">
                <i class="fa fa-code-fork fa-2x"></i>
                <span> Developing</span>
            </div>
            <br />
            <a href="/Developing/Code-Guidelines/">Code Guidelines</a><br />
            <a href="/Developing/Validating-Code/">Validating Code</a><br />
            <a href="/Developing/Using-Git/">Using Git</a><br />
            <strong>More...</strong>
        </div>
    </div>
</div>

==> librenms-1.31.03v0.tgz: librenms/doc/index.md <==
hide_toc: true
<div class="row">
    <div class="col-md-4">
        <div class="well">
            <div class="home-header">
                <i class="fa fa-download fa-2x"></i>
                <span> Installing</span>
            </div>
            <br />
            <a href="/Installation/Installation-Ubuntu-1604-Nginx/">Ubuntu 16.04 + Nginx</a><br />
            <a href="/Installation/Installation-CentOS-7-Nginx/">CentOS 7 + Nginx</a><br />
            <a href="/Installation/Migrating-from-Observium/">Migrating from Observium</a><br />
            <a href="/Installation/Installing-LibreNMS/"><strong>More...</strong></a>
        </div>
    </div>
    <div class="col-md-4">
        <div class="well">
            <div class="home-header">
                <i class="fa fa-plug fa-2x"></i>
                <span> Extensions</span>
            </div>
            <br />
            <a href="/Extensions/Auto-Discovery/">Auto Discovery</a><br />
            <a href="/Extensions/Oxidized/">Oxidized</a><br />
            <a href="/Extensions/RRDCached/">RRDCached</a><br />
            <strong>More...</strong>
        </div>
    </div>
    <div class="col-md-4">
        <div class="well">
            <div class="home-header">
                <i class="fa fa-bell fa-2x"></i>
                <span> Alerting</span>
            </div>
            <br />
            <a href="/Alerting/Rules/#rules">Rules</a><br />
            <a href="/Alerting/Templates/">Templates</a><br />
            <a href="/Alerting/Transports/">Transports</a><br />
            <a href="/Alerting/"><strong>More...</strong></a>
        </div>
    </div>
</div>
<div class="row">
    <div class="col-md-4">
        <div class="well">
            <div class="home-header">
                <i class="fa fa-connectdevelop fa-2x"></i>
                <span> API</span>
            </div>
            <br />
            <a href="/API/">API Docs</a><br>
            <a href="/API/#api-structure">API Structure</a><br>
            <a href="/API/#api-endpoints">API Endpoints</a><br>
            <a href="/API/"><strong>More...</strong></a>
        </div>
    </div>
    <div class="col-md-4">
        <div class="well">
            <div class="home-header">
                <i class="fa fa-ambulance fa-2x"></i>
                <span> Support</span>
            </div>
            <br />
            <a href="/Support/FAQ/">FAQ</a><br />
            <a href="/Support/Install%20Validation/">Install validation</a><br />
            <a href="/Support/Performance/">Performance tweaks</a><br />
            <strong>More...</strong>
        </div>
    </div>
    <div class="col-md-4">
        <div class="well">
            <div class="home-header">
                <i class="fa fa-code-fork fa-2x"></i>
                <span> Developing</span>
            </div>
            <br />
            <a href="/Developing/Code-Guidelines/">Code Guidelines</a><br />
            <a href="/Developing/Validating-Code/">Validating Code</a><br />
            <a href="/Developing/Using-Git/">Using Git</a><br />
            <strong>More...</strong>
        </div>
    </div>
</div>
